# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterUDFResponse(Model):
    """MeterUDFResponse.

    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param udfs: An array of user-defined fields (UDFs)
    :type udfs: list[~energycap.sdk.models.UDFFieldChild]
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'udfs': {'key': 'udfs', 'type': '[UDFFieldChild]'},
    }

    def __init__(self, meter_id=None, meter_code=None, meter_info=None, udfs=None):
        super(MeterUDFResponse, self).__init__()
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.udfs = udfs



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecialAdjustmentMethod(Model):
    """SpecialAdjustmentMethod.

    :param label: The description
    :type label: str
    :param special_adjustment_method_id: The special adjustment method id
    :type special_adjustment_method_id: int
    :param electric_only: The flag which determines if this method is for
     electric meter only
    :type electric_only: bool
    :param symbol: The symbol on value
    :type symbol: str
    :param precision: The precision on value
    :type precision: int
    """

    _attribute_map = {
        'label': {'key': 'label', 'type': 'str'},
        'special_adjustment_method_id': {'key': 'specialAdjustmentMethodId', 'type': 'int'},
        'electric_only': {'key': 'electricOnly', 'type': 'bool'},
        'symbol': {'key': 'symbol', 'type': 'str'},
        'precision': {'key': 'precision', 'type': 'int'},
    }

    def __init__(self, label=None, special_adjustment_method_id=None, electric_only=None, symbol=None, precision=None):
        super(SpecialAdjustmentMethod, self).__init__()
        self.label = label
        self.special_adjustment_method_id = special_adjustment_method_id
        self.electric_only = electric_only
        self.symbol = symbol
        self.precision = precision



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificAuditPropertyEdit(Model):
    """SpecificAuditPropertyEdit.

    :param specific_audit_info: Name used to refer to this audit <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type specific_audit_info: str
    :param alert_severity_info: The alert severity <span
     class='property-internal'>Required</span>
    :type alert_severity_info: str
    :param skip_zero_comparison: Skip Zero Comparison <span
     class='property-internal'>Required</span>
    :type skip_zero_comparison: bool
    :param properties: List of properties and values to assign to the specific
     audit
    :type properties: list[~energycap.sdk.models.SpecificAuditPropertyChild]
    """

    _validation = {
        'specific_audit_info': {'required': True, 'max_length': 64, 'min_length': 0},
        'alert_severity_info': {'required': True},
        'skip_zero_comparison': {'required': True},
    }

    _attribute_map = {
        'specific_audit_info': {'key': 'specificAuditInfo', 'type': 'str'},
        'alert_severity_info': {'key': 'alertSeverityInfo', 'type': 'str'},
        'skip_zero_comparison': {'key': 'skipZeroComparison', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '[SpecificAuditPropertyChild]'},
    }

    def __init__(self, specific_audit_info, alert_severity_info, skip_zero_comparison, properties=None):
        super(SpecificAuditPropertyEdit, self).__init__()
        self.specific_audit_info = specific_audit_info
        self.alert_severity_info = alert_severity_info
        self.skip_zero_comparison = skip_zero_comparison
        self.properties = properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PermissionsRequest(Model):
    """PermissionsRequest.

    :param accounting_settings:
    :type accounting_settings:
     ~energycap.sdk.models.AccountingSettingsClassPermission
    :param accounts:
    :type accounts: ~energycap.sdk.models.AccountsClassPermission
    :param accounts_module:
    :type accounts_module: ~energycap.sdk.models.AccountsModuleClassPermission
    :param accrual_settings:
    :type accrual_settings:
     ~energycap.sdk.models.AccrualSettingsClassPermission
    :param cost_centers:
    :type cost_centers: ~energycap.sdk.models.CostCentersClassPermission
    :param move_accounts_between_vendors:
    :type move_accounts_between_vendors:
     ~energycap.sdk.models.MoveAccountsBetweenVendorsClassPermission
    :param application_settings:
    :type application_settings:
     ~energycap.sdk.models.ApplicationSettingsClassPermission
    :param approve_bills:
    :type approve_bills: ~energycap.sdk.models.ApproveBillsClassPermission
    :param bill_audit_groups:
    :type bill_audit_groups:
     ~energycap.sdk.models.BillAuditGroupsClassPermission
    :param bill_audits:
    :type bill_audits: ~energycap.sdk.models.BillAuditsClassPermission
    :param bill_entry_templates:
    :type bill_entry_templates:
     ~energycap.sdk.models.BillEntryTemplatesClassPermission
    :param bill_workflow_settings:
    :type bill_workflow_settings:
     ~energycap.sdk.models.BillWorkflowSettingsClassPermission
    :param bills_and_batches:
    :type bills_and_batches:
     ~energycap.sdk.models.BillsAndBatchesClassPermission
    :param export_bills:
    :type export_bills: ~energycap.sdk.models.ExportBillsClassPermission
    :param export_hold:
    :type export_hold: ~energycap.sdk.models.ExportHoldClassPermission
    :param move_existing_bills:
    :type move_existing_bills:
     ~energycap.sdk.models.MoveExistingBillsClassPermission
    :param bill_audit_results_and_alerts:
    :type bill_audit_results_and_alerts:
     ~energycap.sdk.models.BillAuditResultsAndAlertsClassPermission
    :param shared_bill_lists:
    :type shared_bill_lists:
     ~energycap.sdk.models.SharedBillListsClassPermission
    :param unit_system_settings:
    :type unit_system_settings:
     ~energycap.sdk.models.UnitSystemSettingsClassPermission
    :param update_approved_bills:
    :type update_approved_bills:
     ~energycap.sdk.models.UpdateApprovedBillsClassPermission
    :param update_units_on_existing_bills:
    :type update_units_on_existing_bills:
     ~energycap.sdk.models.UpdateUnitsOnExistingBillsClassPermission
    :param budgets_and_budget_versions:
    :type budgets_and_budget_versions:
     ~energycap.sdk.models.BudgetsAndBudgetVersionsClassPermission
    :param chargebacks_module:
    :type chargebacks_module:
     ~energycap.sdk.models.ChargebacksModuleClassPermission
    :param chargebacks:
    :type chargebacks: ~energycap.sdk.models.ChargebacksClassPermission
    :param chargeback_reversals:
    :type chargeback_reversals:
     ~energycap.sdk.models.ChargebackReversalsClassPermission
    :param submeter_routes:
    :type submeter_routes: ~energycap.sdk.models.SubmeterRoutesClassPermission
    :param meter_savings_settings:
    :type meter_savings_settings:
     ~energycap.sdk.models.MeterSavingsSettingsClassPermission
    :param savings_adjustments:
    :type savings_adjustments:
     ~energycap.sdk.models.SavingsAdjustmentsClassPermission
    :param manually_adjust_savings:
    :type manually_adjust_savings:
     ~energycap.sdk.models.ManuallyAdjustSavingsClassPermission
    :param savings_engine:
    :type savings_engine: ~energycap.sdk.models.SavingsEngineClassPermission
    :param baseline_engine:
    :type baseline_engine: ~energycap.sdk.models.BaselineEngineClassPermission
    :param global_cost_avoidance_settings:
    :type global_cost_avoidance_settings:
     ~energycap.sdk.models.GlobalCostAvoidanceSettingsClassPermission
    :param dashboard_and_maps_module:
    :type dashboard_and_maps_module:
     ~energycap.sdk.models.DashboardAndMapsModuleClassPermission
    :param dashboard_administrator:
    :type dashboard_administrator:
     ~energycap.sdk.models.DashboardAdministratorClassPermission
    :param public_dashboards_or_maps:
    :type public_dashboards_or_maps:
     ~energycap.sdk.models.PublicDashboardsOrMapsClassPermission
    :param shared_dashboards_or_maps:
    :type shared_dashboards_or_maps:
     ~energycap.sdk.models.SharedDashboardsOrMapsClassPermission
    :param buildings_and_meters_module:
    :type buildings_and_meters_module:
     ~energycap.sdk.models.BuildingsAndMetersModuleClassPermission
    :param groups_and_benchmarks_module:
    :type groups_and_benchmarks_module:
     ~energycap.sdk.models.GroupsAndBenchmarksModuleClassPermission
    :param building_and_meter_groups:
    :type building_and_meter_groups:
     ~energycap.sdk.models.BuildingAndMeterGroupsClassPermission
    :param buildings_and_organizations:
    :type buildings_and_organizations:
     ~energycap.sdk.models.BuildingsAndOrganizationsClassPermission
    :param interval_data:
    :type interval_data: ~energycap.sdk.models.IntervalDataClassPermission
    :param interval_data_analysis:
    :type interval_data_analysis:
     ~energycap.sdk.models.IntervalDataAnalysisClassPermission
    :param energystar_submissions:
    :type energystar_submissions:
     ~energycap.sdk.models.ENERGYSTARSubmissionsClassPermission
    :param facility_projects:
    :type facility_projects:
     ~energycap.sdk.models.FacilityProjectsClassPermission
    :param greenhouse_gas_administrator:
    :type greenhouse_gas_administrator:
     ~energycap.sdk.models.GreenhouseGasAdministratorClassPermission
    :param interval_data_rollup:
    :type interval_data_rollup:
     ~energycap.sdk.models.IntervalDataRollupClassPermission
    :param meters:
    :type meters: ~energycap.sdk.models.MetersClassPermission
    :param normalization_settings:
    :type normalization_settings:
     ~energycap.sdk.models.NormalizationSettingsClassPermission
    :param weather_settings:
    :type weather_settings:
     ~energycap.sdk.models.WeatherSettingsClassPermission
    :param reports_module:
    :type reports_module: ~energycap.sdk.models.ReportsModuleClassPermission
    :param distributed_reports_settings:
    :type distributed_reports_settings:
     ~energycap.sdk.models.DistributedReportsSettingsClassPermission
    :param install_or_update_reports:
    :type install_or_update_reports:
     ~energycap.sdk.models.InstallOrUpdateReportsClassPermission
    :param report_groups:
    :type report_groups: ~energycap.sdk.models.ReportGroupsClassPermission
    :param shared_reports:
    :type shared_reports: ~energycap.sdk.models.SharedReportsClassPermission
    :param reset_user_passwords:
    :type reset_user_passwords:
     ~energycap.sdk.models.ResetUserPasswordsClassPermission
    :param users_and_roles:
    :type users_and_roles: ~energycap.sdk.models.UsersAndRolesClassPermission
    :param vendors_and_rates_module:
    :type vendors_and_rates_module:
     ~energycap.sdk.models.VendorsAndRatesModuleClassPermission
    :param rate_schedules:
    :type rate_schedules: ~energycap.sdk.models.RateSchedulesClassPermission
    :param vendors:
    :type vendors: ~energycap.sdk.models.VendorsClassPermission
    """

    _attribute_map = {
        'accounting_settings': {'key': 'accountingSettings', 'type': 'AccountingSettingsClassPermission'},
        'accounts': {'key': 'accounts', 'type': 'AccountsClassPermission'},
        'accounts_module': {'key': 'accountsModule', 'type': 'AccountsModuleClassPermission'},
        'accrual_settings': {'key': 'accrualSettings', 'type': 'AccrualSettingsClassPermission'},
        'cost_centers': {'key': 'costCenters', 'type': 'CostCentersClassPermission'},
        'move_accounts_between_vendors': {'key': 'moveAccountsBetweenVendors', 'type': 'MoveAccountsBetweenVendorsClassPermission'},
        'application_settings': {'key': 'applicationSettings', 'type': 'ApplicationSettingsClassPermission'},
        'approve_bills': {'key': 'approveBills', 'type': 'ApproveBillsClassPermission'},
        'bill_audit_groups': {'key': 'billAuditGroups', 'type': 'BillAuditGroupsClassPermission'},
        'bill_audits': {'key': 'billAudits', 'type': 'BillAuditsClassPermission'},
        'bill_entry_templates': {'key': 'billEntryTemplates', 'type': 'BillEntryTemplatesClassPermission'},
        'bill_workflow_settings': {'key': 'billWorkflowSettings', 'type': 'BillWorkflowSettingsClassPermission'},
        'bills_and_batches': {'key': 'billsAndBatches', 'type': 'BillsAndBatchesClassPermission'},
        'export_bills': {'key': 'exportBills', 'type': 'ExportBillsClassPermission'},
        'export_hold': {'key': 'exportHold', 'type': 'ExportHoldClassPermission'},
        'move_existing_bills': {'key': 'moveExistingBills', 'type': 'MoveExistingBillsClassPermission'},
        'bill_audit_results_and_alerts': {'key': 'billAuditResultsAndAlerts', 'type': 'BillAuditResultsAndAlertsClassPermission'},
        'shared_bill_lists': {'key': 'sharedBillLists', 'type': 'SharedBillListsClassPermission'},
        'unit_system_settings': {'key': 'unitSystemSettings', 'type': 'UnitSystemSettingsClassPermission'},
        'update_approved_bills': {'key': 'updateApprovedBills', 'type': 'UpdateApprovedBillsClassPermission'},
        'update_units_on_existing_bills': {'key': 'updateUnitsOnExistingBills', 'type': 'UpdateUnitsOnExistingBillsClassPermission'},
        'budgets_and_budget_versions': {'key': 'budgetsAndBudgetVersions', 'type': 'BudgetsAndBudgetVersionsClassPermission'},
        'chargebacks_module': {'key': 'chargebacksModule', 'type': 'ChargebacksModuleClassPermission'},
        'chargebacks': {'key': 'chargebacks', 'type': 'ChargebacksClassPermission'},
        'chargeback_reversals': {'key': 'chargebackReversals', 'type': 'ChargebackReversalsClassPermission'},
        'submeter_routes': {'key': 'submeterRoutes', 'type': 'SubmeterRoutesClassPermission'},
        'meter_savings_settings': {'key': 'meterSavingsSettings', 'type': 'MeterSavingsSettingsClassPermission'},
        'savings_adjustments': {'key': 'savingsAdjustments', 'type': 'SavingsAdjustmentsClassPermission'},
        'manually_adjust_savings': {'key': 'manuallyAdjustSavings', 'type': 'ManuallyAdjustSavingsClassPermission'},
        'savings_engine': {'key': 'savingsEngine', 'type': 'SavingsEngineClassPermission'},
        'baseline_engine': {'key': 'baselineEngine', 'type': 'BaselineEngineClassPermission'},
        'global_cost_avoidance_settings': {'key': 'globalCostAvoidanceSettings', 'type': 'GlobalCostAvoidanceSettingsClassPermission'},
        'dashboard_and_maps_module': {'key': 'dashboardAndMapsModule', 'type': 'DashboardAndMapsModuleClassPermission'},
        'dashboard_administrator': {'key': 'dashboardAdministrator', 'type': 'DashboardAdministratorClassPermission'},
        'public_dashboards_or_maps': {'key': 'publicDashboardsOrMaps', 'type': 'PublicDashboardsOrMapsClassPermission'},
        'shared_dashboards_or_maps': {'key': 'sharedDashboardsOrMaps', 'type': 'SharedDashboardsOrMapsClassPermission'},
        'buildings_and_meters_module': {'key': 'buildingsAndMetersModule', 'type': 'BuildingsAndMetersModuleClassPermission'},
        'groups_and_benchmarks_module': {'key': 'groupsAndBenchmarksModule', 'type': 'GroupsAndBenchmarksModuleClassPermission'},
        'building_and_meter_groups': {'key': 'buildingAndMeterGroups', 'type': 'BuildingAndMeterGroupsClassPermission'},
        'buildings_and_organizations': {'key': 'buildingsAndOrganizations', 'type': 'BuildingsAndOrganizationsClassPermission'},
        'interval_data': {'key': 'intervalData', 'type': 'IntervalDataClassPermission'},
        'interval_data_analysis': {'key': 'intervalDataAnalysis', 'type': 'IntervalDataAnalysisClassPermission'},
        'energystar_submissions': {'key': 'energystarSubmissions', 'type': 'ENERGYSTARSubmissionsClassPermission'},
        'facility_projects': {'key': 'facilityProjects', 'type': 'FacilityProjectsClassPermission'},
        'greenhouse_gas_administrator': {'key': 'greenhouseGasAdministrator', 'type': 'GreenhouseGasAdministratorClassPermission'},
        'interval_data_rollup': {'key': 'intervalDataRollup', 'type': 'IntervalDataRollupClassPermission'},
        'meters': {'key': 'meters', 'type': 'MetersClassPermission'},
        'normalization_settings': {'key': 'normalizationSettings', 'type': 'NormalizationSettingsClassPermission'},
        'weather_settings': {'key': 'weatherSettings', 'type': 'WeatherSettingsClassPermission'},
        'reports_module': {'key': 'reportsModule', 'type': 'ReportsModuleClassPermission'},
        'distributed_reports_settings': {'key': 'distributedReportsSettings', 'type': 'DistributedReportsSettingsClassPermission'},
        'install_or_update_reports': {'key': 'installOrUpdateReports', 'type': 'InstallOrUpdateReportsClassPermission'},
        'report_groups': {'key': 'reportGroups', 'type': 'ReportGroupsClassPermission'},
        'shared_reports': {'key': 'sharedReports', 'type': 'SharedReportsClassPermission'},
        'reset_user_passwords': {'key': 'resetUserPasswords', 'type': 'ResetUserPasswordsClassPermission'},
        'users_and_roles': {'key': 'usersAndRoles', 'type': 'UsersAndRolesClassPermission'},
        'vendors_and_rates_module': {'key': 'vendorsAndRatesModule', 'type': 'VendorsAndRatesModuleClassPermission'},
        'rate_schedules': {'key': 'rateSchedules', 'type': 'RateSchedulesClassPermission'},
        'vendors': {'key': 'vendors', 'type': 'VendorsClassPermission'},
    }

    def __init__(self, accounting_settings=None, accounts=None, accounts_module=None, accrual_settings=None, cost_centers=None, move_accounts_between_vendors=None, application_settings=None, approve_bills=None, bill_audit_groups=None, bill_audits=None, bill_entry_templates=None, bill_workflow_settings=None, bills_and_batches=None, export_bills=None, export_hold=None, move_existing_bills=None, bill_audit_results_and_alerts=None, shared_bill_lists=None, unit_system_settings=None, update_approved_bills=None, update_units_on_existing_bills=None, budgets_and_budget_versions=None, chargebacks_module=None, chargebacks=None, chargeback_reversals=None, submeter_routes=None, meter_savings_settings=None, savings_adjustments=None, manually_adjust_savings=None, savings_engine=None, baseline_engine=None, global_cost_avoidance_settings=None, dashboard_and_maps_module=None, dashboard_administrator=None, public_dashboards_or_maps=None, shared_dashboards_or_maps=None, buildings_and_meters_module=None, groups_and_benchmarks_module=None, building_and_meter_groups=None, buildings_and_organizations=None, interval_data=None, interval_data_analysis=None, energystar_submissions=None, facility_projects=None, greenhouse_gas_administrator=None, interval_data_rollup=None, meters=None, normalization_settings=None, weather_settings=None, reports_module=None, distributed_reports_settings=None, install_or_update_reports=None, report_groups=None, shared_reports=None, reset_user_passwords=None, users_and_roles=None, vendors_and_rates_module=None, rate_schedules=None, vendors=None):
        super(PermissionsRequest, self).__init__()
        self.accounting_settings = accounting_settings
        self.accounts = accounts
        self.accounts_module = accounts_module
        self.accrual_settings = accrual_settings
        self.cost_centers = cost_centers
        self.move_accounts_between_vendors = move_accounts_between_vendors
        self.application_settings = application_settings
        self.approve_bills = approve_bills
        self.bill_audit_groups = bill_audit_groups
        self.bill_audits = bill_audits
        self.bill_entry_templates = bill_entry_templates
        self.bill_workflow_settings = bill_workflow_settings
        self.bills_and_batches = bills_and_batches
        self.export_bills = export_bills
        self.export_hold = export_hold
        self.move_existing_bills = move_existing_bills
        self.bill_audit_results_and_alerts = bill_audit_results_and_alerts
        self.shared_bill_lists = shared_bill_lists
        self.unit_system_settings = unit_system_settings
        self.update_approved_bills = update_approved_bills
        self.update_units_on_existing_bills = update_units_on_existing_bills
        self.budgets_and_budget_versions = budgets_and_budget_versions
        self.chargebacks_module = chargebacks_module
        self.chargebacks = chargebacks
        self.chargeback_reversals = chargeback_reversals
        self.submeter_routes = submeter_routes
        self.meter_savings_settings = meter_savings_settings
        self.savings_adjustments = savings_adjustments
        self.manually_adjust_savings = manually_adjust_savings
        self.savings_engine = savings_engine
        self.baseline_engine = baseline_engine
        self.global_cost_avoidance_settings = global_cost_avoidance_settings
        self.dashboard_and_maps_module = dashboard_and_maps_module
        self.dashboard_administrator = dashboard_administrator
        self.public_dashboards_or_maps = public_dashboards_or_maps
        self.shared_dashboards_or_maps = shared_dashboards_or_maps
        self.buildings_and_meters_module = buildings_and_meters_module
        self.groups_and_benchmarks_module = groups_and_benchmarks_module
        self.building_and_meter_groups = building_and_meter_groups
        self.buildings_and_organizations = buildings_and_organizations
        self.interval_data = interval_data
        self.interval_data_analysis = interval_data_analysis
        self.energystar_submissions = energystar_submissions
        self.facility_projects = facility_projects
        self.greenhouse_gas_administrator = greenhouse_gas_administrator
        self.interval_data_rollup = interval_data_rollup
        self.meters = meters
        self.normalization_settings = normalization_settings
        self.weather_settings = weather_settings
        self.reports_module = reports_module
        self.distributed_reports_settings = distributed_reports_settings
        self.install_or_update_reports = install_or_update_reports
        self.report_groups = report_groups
        self.shared_reports = shared_reports
        self.reset_user_passwords = reset_user_passwords
        self.users_and_roles = users_and_roles
        self.vendors_and_rates_module = vendors_and_rates_module
        self.rate_schedules = rate_schedules
        self.vendors = vendors



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlacePropertyResponse(Model):
    """EnergyStarPlacePropertyResponse.

    :param energy_star_property_id: The energy star place property identifier
    :type energy_star_property_id: int
    :param property_id: The property identifier
    :type property_id: int
    :param effective_date: The effective date
    :type effective_date: datetime
    :param value: The value of the property
    :type value: str
    :param place_type_code: The place type code
    :type place_type_code: str
    :param place_type_info: The place type information
    :type place_type_info: str
    :param datatype: The data type object
    :type datatype: ~energycap.sdk.models.DataTypeResponse
    :param caption: The caption for the property
    :type caption: str
    :param default_value: The default value of the property
    :type default_value: str
    :param min_value: The minimum value of the property
    :type min_value: str
    :param max_value: The maximum value of the property
    :type max_value: str
    :param required: Whether the property is required or not required
    :type required: bool
    """

    _attribute_map = {
        'energy_star_property_id': {'key': 'energyStarPropertyId', 'type': 'int'},
        'property_id': {'key': 'propertyId', 'type': 'int'},
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'str'},
        'place_type_code': {'key': 'placeTypeCode', 'type': 'str'},
        'place_type_info': {'key': 'placeTypeInfo', 'type': 'str'},
        'datatype': {'key': 'datatype', 'type': 'DataTypeResponse'},
        'caption': {'key': 'caption', 'type': 'str'},
        'default_value': {'key': 'defaultValue', 'type': 'str'},
        'min_value': {'key': 'minValue', 'type': 'str'},
        'max_value': {'key': 'maxValue', 'type': 'str'},
        'required': {'key': 'required', 'type': 'bool'},
    }

    def __init__(self, energy_star_property_id=None, property_id=None, effective_date=None, value=None, place_type_code=None, place_type_info=None, datatype=None, caption=None, default_value=None, min_value=None, max_value=None, required=None):
        super(EnergyStarPlacePropertyResponse, self).__init__()
        self.energy_star_property_id = energy_star_property_id
        self.property_id = property_id
        self.effective_date = effective_date
        self.value = value
        self.place_type_code = place_type_code
        self.place_type_info = place_type_info
        self.datatype = datatype
        self.caption = caption
        self.default_value = default_value
        self.min_value = min_value
        self.max_value = max_value
        self.required = required



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TemplateLine(Model):
    """TemplateLine.

    :param template_line_id: The template line identifier
    :type template_line_id: int
    :param begin_day: The begin day
    :type begin_day: int
    :param end_day: The end day
    :type end_day: int
    :param display_order: The display order
    :type display_order: int
    :param caption: The caption
    :type caption: str
    :param help_tag: The help tag
    :type help_tag: str
    :param is_required: Indicates whether a template line value is required or
     not required
    :type is_required: bool
    :param from_prev_template_line_id: The from previous template line
     identifier
    :type from_prev_template_line_id: int
    :param unit: The usage unit
    :type unit: ~energycap.sdk.models.UnitResponse
    :param cost_unit: The cost unit
    :type cost_unit: ~energycap.sdk.models.UnitResponse
    :param commodity: The commodity
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param observation_type: The observation type
    :type observation_type: ~energycap.sdk.models.ObservationType
    """

    _attribute_map = {
        'template_line_id': {'key': 'templateLineId', 'type': 'int'},
        'begin_day': {'key': 'beginDay', 'type': 'int'},
        'end_day': {'key': 'endDay', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
        'help_tag': {'key': 'helpTag', 'type': 'str'},
        'is_required': {'key': 'isRequired', 'type': 'bool'},
        'from_prev_template_line_id': {'key': 'fromPrevTemplateLineId', 'type': 'int'},
        'unit': {'key': 'unit', 'type': 'UnitResponse'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitResponse'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'observation_type': {'key': 'observationType', 'type': 'ObservationType'},
    }

    def __init__(self, template_line_id=None, begin_day=None, end_day=None, display_order=None, caption=None, help_tag=None, is_required=None, from_prev_template_line_id=None, unit=None, cost_unit=None, commodity=None, observation_type=None):
        super(TemplateLine, self).__init__()
        self.template_line_id = template_line_id
        self.begin_day = begin_day
        self.end_day = end_day
        self.display_order = display_order
        self.caption = caption
        self.help_tag = help_tag
        self.is_required = is_required
        self.from_prev_template_line_id = from_prev_template_line_id
        self.unit = unit
        self.cost_unit = cost_unit
        self.commodity = commodity
        self.observation_type = observation_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AlertSeverityResponse(Model):
    """AlertSeverityResponse.

    :param alert_severity_id:
    :type alert_severity_id: int
    :param alert_severity_info:
    :type alert_severity_info: str
    """

    _attribute_map = {
        'alert_severity_id': {'key': 'alertSeverityId', 'type': 'int'},
        'alert_severity_info': {'key': 'alertSeverityInfo', 'type': 'str'},
    }

    def __init__(self, alert_severity_id=None, alert_severity_info=None):
        super(AlertSeverityResponse, self).__init__()
        self.alert_severity_id = alert_severity_id
        self.alert_severity_info = alert_severity_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineProcessorResponseBaselineBill(Model):
    """BaselineProcessorResponseBaselineBill.

    :param bill_id: The bill identifier
    :type bill_id: int
    :param avg_cooling_degree_days: The average cooling degree days
    :type avg_cooling_degree_days: float
    :param avg_heating_degree_days: The average heating degree days
    :type avg_heating_degree_days: float
    :param begin_date: The bill's begin date
    :type begin_date: datetime
    :param end_date: The bill's end date
    :type end_date: datetime
    :param is_excluded: Indicates if the bill is excluded from the baseline
     regression
    :type is_excluded: bool
    :param is_outlier: Indicates if the bill is an outlier
    :type is_outlier: bool
    :param native_use: The native use
    :type native_use: float
    :param days: The number of days in the bill
    :type days: int
    :param period_name: Calendar Period Name
    :type period_name: str
    :param calendar_period: Calendar period
    :type calendar_period: int
    :param calendar_year: Calendar year
    :type calendar_year: int
    :param fiscal_period: Fiscal period
    :type fiscal_period: int
    :param fiscal_year: Fiscal year
    :type fiscal_year: int
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'avg_cooling_degree_days': {'key': 'avgCoolingDegreeDays', 'type': 'float'},
        'avg_heating_degree_days': {'key': 'avgHeatingDegreeDays', 'type': 'float'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'is_excluded': {'key': 'isExcluded', 'type': 'bool'},
        'is_outlier': {'key': 'isOutlier', 'type': 'bool'},
        'native_use': {'key': 'nativeUse', 'type': 'float'},
        'days': {'key': 'days', 'type': 'int'},
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
    }

    def __init__(self, bill_id=None, avg_cooling_degree_days=None, avg_heating_degree_days=None, begin_date=None, end_date=None, is_excluded=None, is_outlier=None, native_use=None, days=None, period_name=None, calendar_period=None, calendar_year=None, fiscal_period=None, fiscal_year=None):
        super(BaselineProcessorResponseBaselineBill, self).__init__()
        self.bill_id = bill_id
        self.avg_cooling_degree_days = avg_cooling_degree_days
        self.avg_heating_degree_days = avg_heating_degree_days
        self.begin_date = begin_date
        self.end_date = end_date
        self.is_excluded = is_excluded
        self.is_outlier = is_outlier
        self.native_use = native_use
        self.days = days
        self.period_name = period_name
        self.calendar_period = calendar_period
        self.calendar_year = calendar_year
        self.fiscal_period = fiscal_period
        self.fiscal_year = fiscal_year



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupMeterGroupResponse(Model):
    """GroupMeterGroupResponse.

    :param meter_group_id: The meter group identifier
    :type meter_group_id: int
    :param meter_group_code: The meter group code
    :type meter_group_code: str
    :param meter_group_info: The meter group info
    :type meter_group_info: str
    :param auto_group: Indicates if this meter group is an autogroup
    :type auto_group: bool
    :param member_count: The number of meters in this group
    :type member_count: int
    :param member_count_with_topmost: The number of meters within the
     currently authenticated user's topmost
    :type member_count_with_topmost: int
    :param meter_group_category: The type of this meter group
    :type meter_group_category: ~energycap.sdk.models.MeterGroupCategoryChild
    :param limit_members_by_topmost: Indicates if the meter group has been set
     limit the list of members by the user's topmost
    :type limit_members_by_topmost: bool
    :param user_defined_auto_group: Indicates if this meter group is an user
     defined auto group
    :type user_defined_auto_group: bool
    :param user_defined_auto_group_filters: The filters applied to determine
     the members of a user defined auto group
    :type user_defined_auto_group_filters:
     list[~energycap.sdk.models.FilterResponse]
    :param last_updated: The last time a member was inserted, updated, or
     deleted from the group
    :type last_updated: datetime
    :param member_commodity_code: The commodity code for the meters in this
     group -
     if all meters belong to the same commodity the commodity code will be used
     here
     if meters belong to different commodities, value will be "MULTIPLE"
     if this group has no meters, value will be ""
    :type member_commodity_code: str
    """

    _attribute_map = {
        'meter_group_id': {'key': 'meterGroupId', 'type': 'int'},
        'meter_group_code': {'key': 'meterGroupCode', 'type': 'str'},
        'meter_group_info': {'key': 'meterGroupInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'member_count': {'key': 'memberCount', 'type': 'int'},
        'member_count_with_topmost': {'key': 'memberCountWithTopmost', 'type': 'int'},
        'meter_group_category': {'key': 'meterGroupCategory', 'type': 'MeterGroupCategoryChild'},
        'limit_members_by_topmost': {'key': 'limitMembersByTopmost', 'type': 'bool'},
        'user_defined_auto_group': {'key': 'userDefinedAutoGroup', 'type': 'bool'},
        'user_defined_auto_group_filters': {'key': 'userDefinedAutoGroupFilters', 'type': '[FilterResponse]'},
        'last_updated': {'key': 'lastUpdated', 'type': 'iso-8601'},
        'member_commodity_code': {'key': 'memberCommodityCode', 'type': 'str'},
    }

    def __init__(self, meter_group_id=None, meter_group_code=None, meter_group_info=None, auto_group=None, member_count=None, member_count_with_topmost=None, meter_group_category=None, limit_members_by_topmost=None, user_defined_auto_group=None, user_defined_auto_group_filters=None, last_updated=None, member_commodity_code=None):
        super(GroupMeterGroupResponse, self).__init__()
        self.meter_group_id = meter_group_id
        self.meter_group_code = meter_group_code
        self.meter_group_info = meter_group_info
        self.auto_group = auto_group
        self.member_count = member_count
        self.member_count_with_topmost = member_count_with_topmost
        self.meter_group_category = meter_group_category
        self.limit_members_by_topmost = limit_members_by_topmost
        self.user_defined_auto_group = user_defined_auto_group
        self.user_defined_auto_group_filters = user_defined_auto_group_filters
        self.last_updated = last_updated
        self.member_commodity_code = member_commodity_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteMeterEdit(Model):
    """RouteMeterEdit.

    :param display_order: The display order of this route meter
    :type display_order: int
    """

    _attribute_map = {
        'display_order': {'key': 'displayOrder', 'type': 'int'},
    }

    def __init__(self, display_order=None):
        super(RouteMeterEdit, self).__init__()
        self.display_order = display_order



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodCostUnitDeltaChild(Model):
    """This data is not currently being used, it has been included for
    completeness.

    :param delta: The change in total cost from the current billing period.
    :type delta: float
    :param cost: The total cost.
    :type cost: float
    :param unit: The cost unit.
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'delta': {'key': 'delta', 'type': 'float'},
        'cost': {'key': 'cost', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, delta=None, cost=None, unit=None):
        super(BillingPeriodCostUnitDeltaChild, self).__init__()
        self.delta = delta
        self.cost = cost
        self.unit = unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillsOverdueFromVendorResponse(Model):
    """BillsOverdueFromVendorResponse.

    :param account:
    :type account: ~energycap.sdk.models.AccountChild
    :param cost_center:
    :type cost_center: ~energycap.sdk.models.CostCenterChild
    :param end_date:
    :type end_date: datetime
    :param direct_cost:
    :type direct_cost: float
    :param days:
    :type days: int
    :param gap_days:
    :type gap_days: int
    :param cost_unit: The cost unit of measure
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'account': {'key': 'account', 'type': 'AccountChild'},
        'cost_center': {'key': 'costCenter', 'type': 'CostCenterChild'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'direct_cost': {'key': 'directCost', 'type': 'float'},
        'days': {'key': 'days', 'type': 'int'},
        'gap_days': {'key': 'gapDays', 'type': 'int'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, account=None, cost_center=None, end_date=None, direct_cost=None, days=None, gap_days=None, cost_unit=None):
        super(BillsOverdueFromVendorResponse, self).__init__()
        self.account = account
        self.cost_center = cost_center
        self.end_date = end_date
        self.direct_cost = direct_cost
        self.days = days
        self.gap_days = gap_days
        self.cost_unit = cost_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpdateResult(Model):
    """UpdateResult.

    :param selected:
    :type selected: int
    :param updated:
    :type updated: int
    """

    _attribute_map = {
        'selected': {'key': 'selected', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'int'},
    }

    def __init__(self, selected=None, updated=None):
        super(UpdateResult, self).__init__()
        self.selected = selected
        self.updated = updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceSizeChild(Model):
    """PlaceSizeChild.

    :param place_size_id:
    :type place_size_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    :param value:
    :type value: float
    :param unit_id:
    :type unit_id: int
    :param unit_code:  <span class='property-internal'>Must be between 0 and
     16 characters</span> <span class='property-internal'>Must be between 0 and
     16 characters</span>
    :type unit_code: str
    :param unit_info:  <span class='property-internal'>Must be between 0 and
     32 characters</span> <span class='property-internal'>Must be between 0 and
     32 characters</span>
    :type unit_info: str
    """

    _validation = {
        'unit_code': {'max_length': 16, 'min_length': 0},
        'unit_info': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'place_size_id': {'key': 'placeSizeId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'unit_id': {'key': 'unitId', 'type': 'int'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'unit_info': {'key': 'unitInfo', 'type': 'str'},
    }

    def __init__(self, place_size_id=None, begin_date=None, end_date=None, value=None, unit_id=None, unit_code=None, unit_info=None):
        super(PlaceSizeChild, self).__init__()
        self.place_size_id = place_size_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.value = value
        self.unit_id = unit_id
        self.unit_code = unit_code
        self.unit_info = unit_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GenericBodylineResponse(Model):
    """Representation of a generic "empty" bodyline which is not associated with a
    specific bill or template.

    :param observation_type: The observation type
    :type observation_type: ~energycap.sdk.models.ObservationTypeChild
    :param caption: The caption
    :type caption: str
    :param calculation_type: The calculation type for the line item.  Either
     "Fixed", "Percentage", or "Subtotal"
    :type calculation_type: str
    :param value: The bodyline's value
    :type value: float
    """

    _attribute_map = {
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChild'},
        'caption': {'key': 'caption', 'type': 'str'},
        'calculation_type': {'key': 'calculationType', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, observation_type=None, caption=None, calculation_type=None, value=None):
        super(GenericBodylineResponse, self).__init__()
        self.observation_type = observation_type
        self.caption = caption
        self.calculation_type = calculation_type
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionSplit(Model):
    """BillActionSplit.

    :param ids: List of billIds that need to be split <span
     class='property-internal'>Cannot be Empty</span>
    :type ids: list[int]
    :param note: Optional note/comment <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    :param batch_settings: Optional BatchSettings. If provided the batch will
     be created with the settings in here.
     The bills generated will inherit bill headers (accounting period, invoice
     number, control code, etc ) from the batch
    :type batch_settings: ~energycap.sdk.models.BatchCreate
    """

    _validation = {
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'ids': {'key': 'ids', 'type': '[int]'},
        'note': {'key': 'note', 'type': 'str'},
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchCreate'},
    }

    def __init__(self, ids=None, note=None, batch_settings=None):
        super(BillActionSplit, self).__init__()
        self.ids = ids
        self.note = note
        self.batch_settings = batch_settings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InputResponse(Model):
    """InputResponse.

    :param name:
    :type name: str
    :param prompt:
    :type prompt: str
    :param help_tag:
    :type help_tag: str
    :param default_value:
    :type default_value: str
    :param calculation:
    :type calculation: int
    :param is_block:
    :type is_block: bool
    :param data_type:
    :type data_type: int
    :param display_order:
    :type display_order: int
    :param observation_type:
    :type observation_type: ~energycap.sdk.models.ObservationTypeChild
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'prompt': {'key': 'prompt', 'type': 'str'},
        'help_tag': {'key': 'helpTag', 'type': 'str'},
        'default_value': {'key': 'defaultValue', 'type': 'str'},
        'calculation': {'key': 'calculation', 'type': 'int'},
        'is_block': {'key': 'isBlock', 'type': 'bool'},
        'data_type': {'key': 'dataType', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChild'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, name=None, prompt=None, help_tag=None, default_value=None, calculation=None, is_block=None, data_type=None, display_order=None, observation_type=None, unit=None):
        super(InputResponse, self).__init__()
        self.name = name
        self.prompt = prompt
        self.help_tag = help_tag
        self.default_value = default_value
        self.calculation = calculation
        self.is_block = is_block
        self.data_type = data_type
        self.display_order = display_order
        self.observation_type = observation_type
        self.unit = unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecialAdjustmentResponse(Model):
    """SpecialAdjustmentResponse.

    :param special_adjustment_id: The special adjustment Identifier
    :type special_adjustment_id: int
    :param index_number: The sequence number
    :type index_number: int
    :param value: The amount
    :type value: float
    :param special_adjustment_method: The special adjustment method
    :type special_adjustment_method:
     ~energycap.sdk.models.AdjustmentBaseMethodChild
    :param frequency: The frequency data of adjustment
    :type frequency: ~energycap.sdk.models.Frequency
    :param comments: The user comments about adjustment
    :type comments: str
    :param created_by_user: The creator user identifier
    :type created_by_user: ~energycap.sdk.models.UserChild
    :param created_date: The date of creation
    :type created_date: datetime
    :param modified_by_user: The modifier user identifier
    :type modified_by_user: ~energycap.sdk.models.UserChild
    :param modified_date: The date of modification
    :type modified_date: datetime
    :param special_adjustment_type: The special adjustment type
    :type special_adjustment_type: ~energycap.sdk.models.SpecialAdjustmentType
    """

    _attribute_map = {
        'special_adjustment_id': {'key': 'specialAdjustmentId', 'type': 'int'},
        'index_number': {'key': 'indexNumber', 'type': 'int'},
        'value': {'key': 'value', 'type': 'float'},
        'special_adjustment_method': {'key': 'specialAdjustmentMethod', 'type': 'AdjustmentBaseMethodChild'},
        'frequency': {'key': 'frequency', 'type': 'Frequency'},
        'comments': {'key': 'comments', 'type': 'str'},
        'created_by_user': {'key': 'createdByUser', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by_user': {'key': 'modifiedByUser', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'special_adjustment_type': {'key': 'specialAdjustmentType', 'type': 'SpecialAdjustmentType'},
    }

    def __init__(self, special_adjustment_id=None, index_number=None, value=None, special_adjustment_method=None, frequency=None, comments=None, created_by_user=None, created_date=None, modified_by_user=None, modified_date=None, special_adjustment_type=None):
        super(SpecialAdjustmentResponse, self).__init__()
        self.special_adjustment_id = special_adjustment_id
        self.index_number = index_number
        self.value = value
        self.special_adjustment_method = special_adjustment_method
        self.frequency = frequency
        self.comments = comments
        self.created_by_user = created_by_user
        self.created_date = created_date
        self.modified_by_user = modified_by_user
        self.modified_date = modified_date
        self.special_adjustment_type = special_adjustment_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderChild(Model):
    """BillHeaderChild.

    :param value:
    :type value: str
    :param required:
    :type required: bool
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
        'required': {'key': 'required', 'type': 'bool'},
    }

    def __init__(self, value=None, required=None):
        super(BillHeaderChild, self).__init__()
        self.value = value
        self.required = required



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LogicalDeviceSearch(Model):
    """LogicalDeviceSearch.

    :param logical_devices: An array of logical devices returned by the search
    :type logical_devices:
     list[~energycap.sdk.models.RouteSearchLogicalDevice]
    :param places: An array of places returned by the search
    :type places: list[~energycap.sdk.models.RouteSearchPlace]
    """

    _attribute_map = {
        'logical_devices': {'key': 'logicalDevices', 'type': '[RouteSearchLogicalDevice]'},
        'places': {'key': 'places', 'type': '[RouteSearchPlace]'},
    }

    def __init__(self, logical_devices=None, places=None):
        super(LogicalDeviceSearch, self).__init__()
        self.logical_devices = logical_devices
        self.places = places



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountsClassPermission(Model):
    """AccountsClassPermission.

    :param view:
    :type view: bool
    :param create:
    :type create: bool
    :param edit:
    :type edit: bool
    :param delete:
    :type delete: bool
    """

    _attribute_map = {
        'view': {'key': 'view', 'type': 'bool'},
        'create': {'key': 'create', 'type': 'bool'},
        'edit': {'key': 'edit', 'type': 'bool'},
        'delete': {'key': 'delete', 'type': 'bool'},
    }

    def __init__(self, view=None, create=None, edit=None, delete=None):
        super(AccountsClassPermission, self).__init__()
        self.view = view
        self.create = create
        self.edit = edit
        self.delete = delete



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Setup(Model):
    """Setup.

    :param type:
    :type type: int
    :param sheet_type:
    :type sheet_type: str
    :param action:
    :type action: str
    :param success:
    :type success: int
    :param failure:
    :type failure: int
    :param skip:
    :type skip: int
    :param kickout:
    :type kickout: str
    :param start:
    :type start: datetime
    :param finish:
    :type finish: datetime
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'int'},
        'sheet_type': {'key': 'sheetType', 'type': 'str'},
        'action': {'key': 'action', 'type': 'str'},
        'success': {'key': 'success', 'type': 'int'},
        'failure': {'key': 'failure', 'type': 'int'},
        'skip': {'key': 'skip', 'type': 'int'},
        'kickout': {'key': 'kickout', 'type': 'str'},
        'start': {'key': 'start', 'type': 'iso-8601'},
        'finish': {'key': 'finish', 'type': 'iso-8601'},
    }

    def __init__(self, type=None, sheet_type=None, action=None, success=None, failure=None, skip=None, kickout=None, start=None, finish=None):
        super(Setup, self).__init__()
        self.type = type
        self.sheet_type = sheet_type
        self.action = action
        self.success = success
        self.failure = failure
        self.skip = skip
        self.kickout = kickout
        self.start = start
        self.finish = finish



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHistoryResponse(Model):
    """BillHistoryResponse.

    :param bill_id: The bill's bill id
    :type bill_id: int
    :param billing_period: The bill's billing period
    :type billing_period: int
    :param begin_date: The bill's begin date
    :type begin_date: datetime
    :param end_date: The bill's end date
    :type end_date: datetime
    :param total_cost: The bill's total cost
    :type total_cost: float
    :param total_cost_unit: The bill's total cost unit
    :type total_cost_unit: ~energycap.sdk.models.UnitChild
    :param void: The bill's void indicator
    :type void: bool
    :param accrual: The bill's accrual indicator
    :type accrual: bool
    :param bill_account_meters: The bill's account-meter summaries
    :type bill_account_meters:
     list[~energycap.sdk.models.BillAccountMeterChild]
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'total_cost_unit': {'key': 'totalCostUnit', 'type': 'UnitChild'},
        'void': {'key': 'void', 'type': 'bool'},
        'accrual': {'key': 'accrual', 'type': 'bool'},
        'bill_account_meters': {'key': 'billAccountMeters', 'type': '[BillAccountMeterChild]'},
    }

    def __init__(self, bill_id=None, billing_period=None, begin_date=None, end_date=None, total_cost=None, total_cost_unit=None, void=None, accrual=None, bill_account_meters=None):
        super(BillHistoryResponse, self).__init__()
        self.bill_id = bill_id
        self.billing_period = billing_period
        self.begin_date = begin_date
        self.end_date = end_date
        self.total_cost = total_cost
        self.total_cost_unit = total_cost_unit
        self.void = void
        self.accrual = accrual
        self.bill_account_meters = bill_account_meters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TaskEdit(Model):
    """TaskEdit.

    :param task_note:  <span class='property-internal'>Required</span>
    :type task_note: str
    """

    _validation = {
        'task_note': {'required': True},
    }

    _attribute_map = {
        'task_note': {'key': 'taskNote', 'type': 'str'},
    }

    def __init__(self, task_note):
        super(TaskEdit, self).__init__()
        self.task_note = task_note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteSearchLogicalDevice(Model):
    """RouteSearchLogicalDevice.

    :param logical_device_id: The logical device identifier
    :type logical_device_id: int
    :param logical_device_code: The logical device code
    :type logical_device_code: str
    :param logical_device_info: The logical device info
    :type logical_device_info: str
    :param commodity: The commodity of the logical device
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param meter_id: The meter identifier
    :type meter_id: int
    :param active: Indicates if the meter is active or inactive
    :type active: bool
    :param logical_device_type_id: The logical device type identifier
    :type logical_device_type_id: int
    """

    _attribute_map = {
        'logical_device_id': {'key': 'logicalDeviceId', 'type': 'int'},
        'logical_device_code': {'key': 'logicalDeviceCode', 'type': 'str'},
        'logical_device_info': {'key': 'logicalDeviceInfo', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'active': {'key': 'active', 'type': 'bool'},
        'logical_device_type_id': {'key': 'logicalDeviceTypeId', 'type': 'int'},
    }

    def __init__(self, logical_device_id=None, logical_device_code=None, logical_device_info=None, commodity=None, meter_id=None, active=None, logical_device_type_id=None):
        super(RouteSearchLogicalDevice, self).__init__()
        self.logical_device_id = logical_device_id
        self.logical_device_code = logical_device_code
        self.logical_device_info = logical_device_info
        self.commodity = commodity
        self.meter_id = meter_id
        self.active = active
        self.logical_device_type_id = logical_device_type_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterBillResponse(Model):
    """MeterBillResponse.

    :param bill_id: The bill identifier
    :type bill_id: int
    :param batch: The batch to which this bill belongs
    :type batch: ~energycap.sdk.models.BatchChild
    :param account: The bill's account
    :type account: ~energycap.sdk.models.AccountChild
    :param begin_date: The bill's begin date
    :type begin_date: datetime
    :param end_date: The bill's end date
    :type end_date: datetime
    :param billing_period: The bill's billing period
    :type billing_period: int
    :param account_period: The bill's accounting period
    :type account_period: int
    :param cost: The meter's bill cost
    :type cost: float
    :param cost_per_day: The meter's bill cost per date
    :type cost_per_day: float
    :param cost_per_unit: The meter's bill cost per unit
    :type cost_per_unit: float
    :param estimated: Indicates if the bill is estimated
    :type estimated: bool
    :param approved: Indicates if the bill has been approved
    :type approved: bool
    :param approve_date: The date and time the bill was approved
    :type approve_date: datetime
    :param approved_by: The user who approved the bill
    :type approved_by: ~energycap.sdk.models.UserChild
    :param exported: Indicates if the bill has been exported
    :type exported: bool
    :param export_date: The date and time the bill was exported
    :type export_date: datetime
    :param exported_by: The user who exported the bill
    :type exported_by: ~energycap.sdk.models.UserChild
    :param observation_method: The bill's observation method. Possible values
     include "Automatic", "Manual", "Estimated", "Simulated", "Accrual" and
     "Adjustment"
    :type observation_method: ~energycap.sdk.models.ObservationMethodChild
    :param statement_date: The date and time of the bill statement
    :type statement_date: datetime
    :param due_date: The date and time the bill is due
    :type due_date: datetime
    :param next_reading: The date and time of the next reading
    :type next_reading: datetime
    :param control_code: The bill's control code
    :type control_code: str
    :param invoice_number: The bill's invoice number
    :type invoice_number: str
    :param invoice_pages: The number of pages on the invoice
    :type invoice_pages: int
    :param check_number: The check number
    :type check_number: str
    :param check_date: The date and time of the check
    :type check_date: datetime
    :param pay_status: The pay status of the bill
    :type pay_status: str
    :param cleared_date: The cleared date
    :type cleared_date: datetime
    :param created_by: The user who created the bill
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the bill was created
    :type created_date: datetime
    :param modified_by: The most recent user to modify the bill
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification
    :type modified_date: datetime
    :param void: Indicates if the bill has been voided
    :type void: bool
    :param dirty: Indicates if the bill record has been cleaned. Cleaning is
     an internal EnergyCAP process
    :type dirty: bool
    :param import_verified: Indicates if the import has been verified
    :type import_verified: bool
    :param accrual: Indicates if the bill is an acrrual
    :type accrual: bool
    :param accrual_reversed: Indicates if the bill is a reversed accrual
    :type accrual_reversed: bool
    :param accrual_reversed_date: The date and time the accrual was reversed
    :type accrual_reversed_date: datetime
    :param export_hold: Indicates if the bill is held for export
    :type export_hold: bool
    :param gl_exported: Indicates if the bill has been gl exported
    :type gl_exported: bool
    :param gl_exported_by: The user who exported the bill to gl
    :type gl_exported_by: ~energycap.sdk.models.UserChild
    :param gl_export_date: The date and time the bill was exported to gl
    :type gl_export_date: datetime
    :param from_vendor: Indicates if the bill is from a vendor
    :type from_vendor: bool
    :param has_been_split: Indicates if the bill has been split
    :type has_been_split: bool
    :param was_split_date: The date and time the bill was split
    :type was_split_date: datetime
    :param trans_ref_num: The transaction reference number of the bill
    :type trans_ref_num: str
    :param payment_type: The payment type of the bill
    :type payment_type: str
    :param actual_amount_paid: The actual amount paid
    :type actual_amount_paid: float
    :param assigned_to: The user who the bill is assigned to
    :type assigned_to: ~energycap.sdk.models.UserChild
    :param assigned_date: The date and time the bill was assigned to a user
    :type assigned_date: datetime
    :param pay_source: The bill's pay source
    :type pay_source: str
    :param pay_to: Indicates whom the bill paid
    :type pay_to: str
    :param previous_balance: The balance of the previous bill
    :type previous_balance: float
    :param balance_forward: The amount of balance that was forwarded
    :type balance_forward: float
    :param current_charges: The current charges
    :type current_charges: float
    :param usage: The meter's usage
    :type usage: float
    :param use_per_day: The meter's usage per day
    :type use_per_day: float
    :param use_unit: The meter's usage unit
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param actual_demand: The meter's actual demand
    :type actual_demand: float
    :param actual_demand_unit: The meter's actual demand unit
    :type actual_demand_unit: ~energycap.sdk.models.UnitChild
    :param billed_demand: The meter's billed demand
    :type billed_demand: float
    :param billed_demand_unit: The meter's billed demand unit
    :type billed_demand_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'batch': {'key': 'batch', 'type': 'BatchChild'},
        'account': {'key': 'account', 'type': 'AccountChild'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'account_period': {'key': 'accountPeriod', 'type': 'int'},
        'cost': {'key': 'cost', 'type': 'float'},
        'cost_per_day': {'key': 'costPerDay', 'type': 'float'},
        'cost_per_unit': {'key': 'costPerUnit', 'type': 'float'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'approved': {'key': 'approved', 'type': 'bool'},
        'approve_date': {'key': 'approveDate', 'type': 'iso-8601'},
        'approved_by': {'key': 'approvedBy', 'type': 'UserChild'},
        'exported': {'key': 'exported', 'type': 'bool'},
        'export_date': {'key': 'exportDate', 'type': 'iso-8601'},
        'exported_by': {'key': 'exportedBy', 'type': 'UserChild'},
        'observation_method': {'key': 'observationMethod', 'type': 'ObservationMethodChild'},
        'statement_date': {'key': 'statementDate', 'type': 'iso-8601'},
        'due_date': {'key': 'dueDate', 'type': 'iso-8601'},
        'next_reading': {'key': 'nextReading', 'type': 'iso-8601'},
        'control_code': {'key': 'controlCode', 'type': 'str'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'str'},
        'invoice_pages': {'key': 'invoicePages', 'type': 'int'},
        'check_number': {'key': 'checkNumber', 'type': 'str'},
        'check_date': {'key': 'checkDate', 'type': 'iso-8601'},
        'pay_status': {'key': 'payStatus', 'type': 'str'},
        'cleared_date': {'key': 'clearedDate', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'void': {'key': 'void', 'type': 'bool'},
        'dirty': {'key': 'dirty', 'type': 'bool'},
        'import_verified': {'key': 'importVerified', 'type': 'bool'},
        'accrual': {'key': 'accrual', 'type': 'bool'},
        'accrual_reversed': {'key': 'accrualReversed', 'type': 'bool'},
        'accrual_reversed_date': {'key': 'accrualReversedDate', 'type': 'iso-8601'},
        'export_hold': {'key': 'exportHold', 'type': 'bool'},
        'gl_exported': {'key': 'glExported', 'type': 'bool'},
        'gl_exported_by': {'key': 'glExportedBy', 'type': 'UserChild'},
        'gl_export_date': {'key': 'glExportDate', 'type': 'iso-8601'},
        'from_vendor': {'key': 'fromVendor', 'type': 'bool'},
        'has_been_split': {'key': 'hasBeenSplit', 'type': 'bool'},
        'was_split_date': {'key': 'wasSplitDate', 'type': 'iso-8601'},
        'trans_ref_num': {'key': 'transRefNum', 'type': 'str'},
        'payment_type': {'key': 'paymentType', 'type': 'str'},
        'actual_amount_paid': {'key': 'actualAmountPaid', 'type': 'float'},
        'assigned_to': {'key': 'assignedTo', 'type': 'UserChild'},
        'assigned_date': {'key': 'assignedDate', 'type': 'iso-8601'},
        'pay_source': {'key': 'paySource', 'type': 'str'},
        'pay_to': {'key': 'payTo', 'type': 'str'},
        'previous_balance': {'key': 'previousBalance', 'type': 'float'},
        'balance_forward': {'key': 'balanceForward', 'type': 'float'},
        'current_charges': {'key': 'currentCharges', 'type': 'float'},
        'usage': {'key': 'usage', 'type': 'float'},
        'use_per_day': {'key': 'usePerDay', 'type': 'float'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'actual_demand': {'key': 'actualDemand', 'type': 'float'},
        'actual_demand_unit': {'key': 'actualDemandUnit', 'type': 'UnitChild'},
        'billed_demand': {'key': 'billedDemand', 'type': 'float'},
        'billed_demand_unit': {'key': 'billedDemandUnit', 'type': 'UnitChild'},
    }

    def __init__(self, bill_id=None, batch=None, account=None, begin_date=None, end_date=None, billing_period=None, account_period=None, cost=None, cost_per_day=None, cost_per_unit=None, estimated=None, approved=None, approve_date=None, approved_by=None, exported=None, export_date=None, exported_by=None, observation_method=None, statement_date=None, due_date=None, next_reading=None, control_code=None, invoice_number=None, invoice_pages=None, check_number=None, check_date=None, pay_status=None, cleared_date=None, created_by=None, created_date=None, modified_by=None, modified_date=None, void=None, dirty=None, import_verified=None, accrual=None, accrual_reversed=None, accrual_reversed_date=None, export_hold=None, gl_exported=None, gl_exported_by=None, gl_export_date=None, from_vendor=None, has_been_split=None, was_split_date=None, trans_ref_num=None, payment_type=None, actual_amount_paid=None, assigned_to=None, assigned_date=None, pay_source=None, pay_to=None, previous_balance=None, balance_forward=None, current_charges=None, usage=None, use_per_day=None, use_unit=None, actual_demand=None, actual_demand_unit=None, billed_demand=None, billed_demand_unit=None):
        super(MeterBillResponse, self).__init__()
        self.bill_id = bill_id
        self.batch = batch
        self.account = account
        self.begin_date = begin_date
        self.end_date = end_date
        self.billing_period = billing_period
        self.account_period = account_period
        self.cost = cost
        self.cost_per_day = cost_per_day
        self.cost_per_unit = cost_per_unit
        self.estimated = estimated
        self.approved = approved
        self.approve_date = approve_date
        self.approved_by = approved_by
        self.exported = exported
        self.export_date = export_date
        self.exported_by = exported_by
        self.observation_method = observation_method
        self.statement_date = statement_date
        self.due_date = due_date
        self.next_reading = next_reading
        self.control_code = control_code
        self.invoice_number = invoice_number
        self.invoice_pages = invoice_pages
        self.check_number = check_number
        self.check_date = check_date
        self.pay_status = pay_status
        self.cleared_date = cleared_date
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.void = void
        self.dirty = dirty
        self.import_verified = import_verified
        self.accrual = accrual
        self.accrual_reversed = accrual_reversed
        self.accrual_reversed_date = accrual_reversed_date
        self.export_hold = export_hold
        self.gl_exported = gl_exported
        self.gl_exported_by = gl_exported_by
        self.gl_export_date = gl_export_date
        self.from_vendor = from_vendor
        self.has_been_split = has_been_split
        self.was_split_date = was_split_date
        self.trans_ref_num = trans_ref_num
        self.payment_type = payment_type
        self.actual_amount_paid = actual_amount_paid
        self.assigned_to = assigned_to
        self.assigned_date = assigned_date
        self.pay_source = pay_source
        self.pay_to = pay_to
        self.previous_balance = previous_balance
        self.balance_forward = balance_forward
        self.current_charges = current_charges
        self.usage = usage
        self.use_per_day = use_per_day
        self.use_unit = use_unit
        self.actual_demand = actual_demand
        self.actual_demand_unit = actual_demand_unit
        self.billed_demand = billed_demand
        self.billed_demand_unit = billed_demand_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Message(Model):
    """This class represents a message from the savings processor.

    :param message_type:
    :type message_type: str
    :param message:
    :type message: str
    """

    _attribute_map = {
        'message_type': {'key': 'messageType', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, message_type=None, message=None):
        super(Message, self).__init__()
        self.message_type = message_type
        self.message = message



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ObservationMethod(Model):
    """ObservationMethod.

    :param observation_method_id: The observation method identifier
    :type observation_method_id: int
    :param observation_method_code: The observation method code
    :type observation_method_code: str
    :param observation_method_info: The observation method info
    :type observation_method_info: str
    """

    _attribute_map = {
        'observation_method_id': {'key': 'observationMethodId', 'type': 'int'},
        'observation_method_code': {'key': 'observationMethodCode', 'type': 'str'},
        'observation_method_info': {'key': 'observationMethodInfo', 'type': 'str'},
    }

    def __init__(self, observation_method_id=None, observation_method_code=None, observation_method_info=None):
        super(ObservationMethod, self).__init__()
        self.observation_method_id = observation_method_id
        self.observation_method_code = observation_method_code
        self.observation_method_info = observation_method_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelEdit(Model):
    """ChannelEdit.

    :param observation_type_code: The channel's observation type code <span
     class='property-internal'>Required</span>
    :type observation_type_code: str
    :param observation_method_code: The channel's observation method code .
     Possible values include "Automatic", "Manual", "Simulated" <span
     class='property-internal'>Required</span>
    :type observation_method_code: str
    :param observation_rule_code: The channel's observation rule code.
     Possible values include "Odometer" and "Trip" <span
     class='property-internal'>Required</span>
    :type observation_rule_code: str
    :param unit_code: The channel's unit code <span
     class='property-internal'>Required</span>
    :type unit_code: str
    :param interval_minutes: The channel's interval. The interval is measured
     in minutes <span class='property-internal'>Must be between 1 and
     2147483647</span>
    :type interval_minutes: int
    :param hidden: Indicates if the channel is hidden
    :type hidden: bool
    :param total_sum: The total sum of the channel
    :type total_sum: bool
    :param auto_summarize: Indicates if the channels reading is auto
     summarized.
     To enable the interval must be monthly, multiplier must be 1, observation
     type must be Reading use or Reading demand, unit must be Value and
     observation method must be Trip.
    :type auto_summarize: bool
    :param channel_import_id: The import identifier for the channel. <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type channel_import_id: str
    :param maximum_reading: The channel's maximum reading <span
     class='property-internal'>Required when observationmethodcode is set to
     odometer</span> <span class='property-internal'>Must be between 1 and
     9999999999</span>
    :type maximum_reading: long
    :param multiplier: The channel multiplier. If no value is provided, a
     default value of
     `1` is used. There are a total of 13 digits allowed including the decimal
     place.
    :type multiplier: float
    :param properties: An object with channel properties
    :type properties: ~energycap.sdk.models.DeviceChannelChild
    """

    _validation = {
        'observation_type_code': {'required': True},
        'observation_method_code': {'required': True},
        'observation_rule_code': {'required': True},
        'unit_code': {'required': True},
        'interval_minutes': {'maximum': 2147483647, 'minimum': 1},
        'channel_import_id': {'max_length': 255, 'min_length': 0},
        'maximum_reading': {'minimum': 1},
    }

    _attribute_map = {
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'observation_method_code': {'key': 'observationMethodCode', 'type': 'str'},
        'observation_rule_code': {'key': 'observationRuleCode', 'type': 'str'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'interval_minutes': {'key': 'intervalMinutes', 'type': 'int'},
        'hidden': {'key': 'hidden', 'type': 'bool'},
        'total_sum': {'key': 'totalSum', 'type': 'bool'},
        'auto_summarize': {'key': 'autoSummarize', 'type': 'bool'},
        'channel_import_id': {'key': 'channelImportId', 'type': 'str'},
        'maximum_reading': {'key': 'maximumReading', 'type': 'long'},
        'multiplier': {'key': 'multiplier', 'type': 'float'},
        'properties': {'key': 'properties', 'type': 'DeviceChannelChild'},
    }

    def __init__(self, observation_type_code, observation_method_code, observation_rule_code, unit_code, interval_minutes=None, hidden=None, total_sum=None, auto_summarize=None, channel_import_id=None, maximum_reading=None, multiplier=None, properties=None):
        super(ChannelEdit, self).__init__()
        self.observation_type_code = observation_type_code
        self.observation_method_code = observation_method_code
        self.observation_rule_code = observation_rule_code
        self.unit_code = unit_code
        self.interval_minutes = interval_minutes
        self.hidden = hidden
        self.total_sum = total_sum
        self.auto_summarize = auto_summarize
        self.channel_import_id = channel_import_id
        self.maximum_reading = maximum_reading
        self.multiplier = multiplier
        self.properties = properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchPlaceChildSearchPlaceChild(Model):
    """SearchPlaceChildSearchPlaceChild.

    :param place_id: The place identifier
    :type place_id: int
    :param place_code: The place code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type place_code: str
    :param place_info: The place info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type place_info: str
    :param place_type: The place type
    :type place_type: ~energycap.sdk.models.PlaceTypeResponse
    :param address: The address of the place
    :type address: ~energycap.sdk.models.AddressChild
    :param parent_path: The collection of places representing the path to its
     parent
    :type parent_path: list[~energycap.sdk.models.SearchParentPlaceChild]
    """

    _validation = {
        'place_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'place_info': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_type': {'key': 'placeType', 'type': 'PlaceTypeResponse'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'parent_path': {'key': 'parentPath', 'type': '[SearchParentPlaceChild]'},
    }

    def __init__(self, place_code, place_info, place_id=None, place_type=None, address=None, parent_path=None):
        super(SearchPlaceChildSearchPlaceChild, self).__init__()
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.place_type = place_type
        self.address = address
        self.parent_path = parent_path



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingRouteResponse(Model):
    """ReadingRouteResponse.

    :param channel: Data representing the channel containing the reading
    :type channel: ~energycap.sdk.models.ChannelResponse
    :param previous_reading: The most recent reading previous to the current
     reading
    :type previous_reading: ~energycap.sdk.models.ReadingChild
    :param reading: Data representing the reading
    :type reading: ~energycap.sdk.models.ReadingChild
    :param display_order: The display order of the meter on the route
    :type display_order: int
    """

    _attribute_map = {
        'channel': {'key': 'channel', 'type': 'ChannelResponse'},
        'previous_reading': {'key': 'previousReading', 'type': 'ReadingChild'},
        'reading': {'key': 'reading', 'type': 'ReadingChild'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
    }

    def __init__(self, channel=None, previous_reading=None, reading=None, display_order=None):
        super(ReadingRouteResponse, self).__init__()
        self.channel = channel
        self.previous_reading = previous_reading
        self.reading = reading
        self.display_order = display_order



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListCreateResponse(Model):
    """ListCreateResponse.

    :param list_id:
    :type list_id: int
    :param list_info:
    :type list_info: str
    :param list_description:
    :type list_description: str
    :param list_type:
    :type list_type: ~energycap.sdk.models.ListTypeChild
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param shared_list:
    :type shared_list: bool
    """

    _attribute_map = {
        'list_id': {'key': 'listId', 'type': 'int'},
        'list_info': {'key': 'listInfo', 'type': 'str'},
        'list_description': {'key': 'listDescription', 'type': 'str'},
        'list_type': {'key': 'listType', 'type': 'ListTypeChild'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'shared_list': {'key': 'sharedList', 'type': 'bool'},
    }

    def __init__(self, list_id=None, list_info=None, list_description=None, list_type=None, user=None, shared_list=None):
        super(ListCreateResponse, self).__init__()
        self.list_id = list_id
        self.list_info = list_info
        self.list_description = list_description
        self.list_type = list_type
        self.user = user
        self.shared_list = shared_list



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Stream(Model):
    """Stream.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar can_read:
    :vartype can_read: bool
    :ivar can_seek:
    :vartype can_seek: bool
    :ivar can_timeout:
    :vartype can_timeout: bool
    :ivar can_write:
    :vartype can_write: bool
    :ivar length:
    :vartype length: long
    :param position:
    :type position: long
    :param read_timeout:
    :type read_timeout: int
    :param write_timeout:
    :type write_timeout: int
    """

    _validation = {
        'can_read': {'readonly': True},
        'can_seek': {'readonly': True},
        'can_timeout': {'readonly': True},
        'can_write': {'readonly': True},
        'length': {'readonly': True},
    }

    _attribute_map = {
        'can_read': {'key': 'canRead', 'type': 'bool'},
        'can_seek': {'key': 'canSeek', 'type': 'bool'},
        'can_timeout': {'key': 'canTimeout', 'type': 'bool'},
        'can_write': {'key': 'canWrite', 'type': 'bool'},
        'length': {'key': 'length', 'type': 'long'},
        'position': {'key': 'position', 'type': 'long'},
        'read_timeout': {'key': 'readTimeout', 'type': 'int'},
        'write_timeout': {'key': 'writeTimeout', 'type': 'int'},
    }

    def __init__(self, position=None, read_timeout=None, write_timeout=None):
        super(Stream, self).__init__()
        self.can_read = None
        self.can_seek = None
        self.can_timeout = None
        self.can_write = None
        self.length = None
        self.position = position
        self.read_timeout = read_timeout
        self.write_timeout = write_timeout



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BodylineResponse(Model):
    """BodylineResponse.

    :param bodyline_id: The bodyline identifier
    :type bodyline_id: int
    :param bill_id: The bill identifier
    :type bill_id: int
    :param value: The bodyline's value
    :type value: float
    :param cost: The cost attributed to the bodyline
    :type cost: float
    :param display_order: The display order
    :type display_order: int
    :param caption: The caption
    :type caption: str
    :param help_tag: The help tag
    :type help_tag: str
    :param commodity: The bodyline's commodity
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param meter: The meter this bodyline is assigned to
    :type meter: ~energycap.sdk.models.MeterChild
    :param account: The Account this bodyline is assigned to
    :type account: ~energycap.sdk.models.AccountChild
    :param general_ledger: The general ledger for this bodyline
    :type general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    :param observation_type: The bodyline's observation type
    :type observation_type: ~energycap.sdk.models.ObservationTypeChild
    :param unit: The bodyline's unit of measure
    :type unit: ~energycap.sdk.models.UnitChild
    :param cost_unit: The bodyline's cost unit of measure for this
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'bodyline_id': {'key': 'bodylineId', 'type': 'int'},
        'bill_id': {'key': 'billId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'float'},
        'cost': {'key': 'cost', 'type': 'float'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
        'help_tag': {'key': 'helpTag', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'account': {'key': 'account', 'type': 'AccountChild'},
        'general_ledger': {'key': 'generalLedger', 'type': 'GeneralLedgerChild'},
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChild'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, bodyline_id=None, bill_id=None, value=None, cost=None, display_order=None, caption=None, help_tag=None, commodity=None, meter=None, account=None, general_ledger=None, observation_type=None, unit=None, cost_unit=None):
        super(BodylineResponse, self).__init__()
        self.bodyline_id = bodyline_id
        self.bill_id = bill_id
        self.value = value
        self.cost = cost
        self.display_order = display_order
        self.caption = caption
        self.help_tag = help_tag
        self.commodity = commodity
        self.meter = meter
        self.account = account
        self.general_ledger = general_ledger
        self.observation_type = observation_type
        self.unit = unit
        self.cost_unit = cost_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecialAdjustmentType(Model):
    """SpecialAdjustmentType.

    :param special_adjustment_type_id:
    :type special_adjustment_type_id: int
    :param special_adjustment_type_code:
    :type special_adjustment_type_code: str
    :param special_adjustment_type_info:
    :type special_adjustment_type_info: str
    """

    _attribute_map = {
        'special_adjustment_type_id': {'key': 'specialAdjustmentTypeId', 'type': 'int'},
        'special_adjustment_type_code': {'key': 'specialAdjustmentTypeCode', 'type': 'str'},
        'special_adjustment_type_info': {'key': 'specialAdjustmentTypeInfo', 'type': 'str'},
    }

    def __init__(self, special_adjustment_type_id=None, special_adjustment_type_code=None, special_adjustment_type_info=None):
        super(SpecialAdjustmentType, self).__init__()
        self.special_adjustment_type_id = special_adjustment_type_id
        self.special_adjustment_type_code = special_adjustment_type_code
        self.special_adjustment_type_info = special_adjustment_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateVersionResponse(Model):
    """RateVersionResponse.

    :param version_id:
    :type version_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    :param created_date:
    :type created_date: datetime
    :param modified_date:
    :type modified_date: datetime
    :param note:
    :type note: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param rate_properties:
    :type rate_properties: list[~energycap.sdk.models.InputResponse]
    :param meter_details:
    :type meter_details: list[~energycap.sdk.models.InputResponse]
    :param bill_calculations:
    :type bill_calculations: list[~energycap.sdk.models.InputResponse]
    :param meter_properties:
    :type meter_properties: list[~energycap.sdk.models.InputResponse]
    :param account_properties:
    :type account_properties: list[~energycap.sdk.models.InputResponse]
    """

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'rate_properties': {'key': 'rateProperties', 'type': '[InputResponse]'},
        'meter_details': {'key': 'meterDetails', 'type': '[InputResponse]'},
        'bill_calculations': {'key': 'billCalculations', 'type': '[InputResponse]'},
        'meter_properties': {'key': 'meterProperties', 'type': '[InputResponse]'},
        'account_properties': {'key': 'accountProperties', 'type': '[InputResponse]'},
    }

    def __init__(self, version_id=None, begin_date=None, end_date=None, created_date=None, modified_date=None, note=None, created_by=None, modified_by=None, rate_properties=None, meter_details=None, bill_calculations=None, meter_properties=None, account_properties=None):
        super(RateVersionResponse, self).__init__()
        self.version_id = version_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.created_date = created_date
        self.modified_date = modified_date
        self.note = note
        self.created_by = created_by
        self.modified_by = modified_by
        self.rate_properties = rate_properties
        self.meter_details = meter_details
        self.bill_calculations = bill_calculations
        self.meter_properties = meter_properties
        self.account_properties = account_properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillIdsBillAlertBulkRequest(Model):
    """BillIdsBillAlertBulkRequest.

    :param bill_ids:  <span class='property-internal'>Cannot be Empty</span>
    :type bill_ids: list[int]
    :param alert_severity_info:
    :type alert_severity_info: str
    :param alert_status_info:  <span class='property-internal'>One of problem,
     fixed, ignored </span>
    :type alert_status_info: str
    :param comment:  <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type comment: str
    """

    _validation = {
        'comment': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'alert_severity_info': {'key': 'alertSeverityInfo', 'type': 'str'},
        'alert_status_info': {'key': 'alertStatusInfo', 'type': 'str'},
        'comment': {'key': 'comment', 'type': 'str'},
    }

    def __init__(self, bill_ids=None, alert_severity_info=None, alert_status_info=None, comment=None):
        super(BillIdsBillAlertBulkRequest, self).__init__()
        self.bill_ids = bill_ids
        self.alert_severity_info = alert_severity_info
        self.alert_status_info = alert_status_info
        self.comment = comment



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateResponseChild(Model):
    """BillHeaderUpdateResponseChild.

    :param bill_id:
    :type bill_id: int
    :param is_updated:
    :type is_updated: bool
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'is_updated': {'key': 'isUpdated', 'type': 'bool'},
    }

    def __init__(self, bill_id=None, is_updated=None):
        super(BillHeaderUpdateResponseChild, self).__init__()
        self.bill_id = bill_id
        self.is_updated = is_updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateDigestActualYearlyResponse(Model):
    """RateDigestActualYearlyResponse.

    :param name: The rate name
    :type name: str
    :param rate_id: The rate identifier
    :type rate_id: int
    :param global_use_unit: The use unit of measure
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit: The cost unit of measure
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.RateDigestActualYearlyResponseResults]
    :param commodities: An array of yearly data per commodity
    :type commodities:
     list[~energycap.sdk.models.RateDigestActualYearlyResponseCommodityData]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'rate_id': {'key': 'rateId', 'type': 'int'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'results': {'key': 'results', 'type': '[RateDigestActualYearlyResponseResults]'},
        'commodities': {'key': 'commodities', 'type': '[RateDigestActualYearlyResponseCommodityData]'},
    }

    def __init__(self, name=None, rate_id=None, global_use_unit=None, cost_unit=None, updated=None, results=None, commodities=None):
        super(RateDigestActualYearlyResponse, self).__init__()
        self.name = name
        self.rate_id = rate_id
        self.global_use_unit = global_use_unit
        self.cost_unit = cost_unit
        self.updated = updated
        self.results = results
        self.commodities = commodities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteResponse(Model):
    """RouteResponse.

    :param route_id: The route identifier
    :type route_id: int
    :param route_info: The route info
    :type route_info: str
    :param route_code: The route code
    :type route_code: str
    :param last_imported: The date and time of the last import
    :type last_imported: datetime
    :param last_exported: The date and time of the last export
    :type last_exported: datetime
    :param last_reading: The date and time and of the last reading
    :type last_reading: datetime
    :param meters: An array of meters belonging to the route
    :type meters: list[~energycap.sdk.models.RouteMeterChild]
    """

    _attribute_map = {
        'route_id': {'key': 'routeId', 'type': 'int'},
        'route_info': {'key': 'routeInfo', 'type': 'str'},
        'route_code': {'key': 'routeCode', 'type': 'str'},
        'last_imported': {'key': 'lastImported', 'type': 'iso-8601'},
        'last_exported': {'key': 'lastExported', 'type': 'iso-8601'},
        'last_reading': {'key': 'lastReading', 'type': 'iso-8601'},
        'meters': {'key': 'meters', 'type': '[RouteMeterChild]'},
    }

    def __init__(self, route_id=None, route_info=None, route_code=None, last_imported=None, last_exported=None, last_reading=None, meters=None):
        super(RouteResponse, self).__init__()
        self.route_id = route_id
        self.route_info = route_info
        self.route_code = route_code
        self.last_imported = last_imported
        self.last_exported = last_exported
        self.last_reading = last_reading
        self.meters = meters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateChildResponse(Model):
    """RateChildResponse.

    :param rate_id:
    :type rate_id: int
    :param name:
    :type name: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    """

    _attribute_map = {
        'rate_id': {'key': 'rateId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
    }

    def __init__(self, rate_id=None, name=None, commodity=None):
        super(RateChildResponse, self).__init__()
        self.rate_id = rate_id
        self.name = name
        self.commodity = commodity
